@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-books" "0.3.1"
+(define-package "org-books" "20251022.1020"
   "Reading list management with Org mode and helm."
   '((enlive   "0.0.1")
     (s        "1.11.0")
